// Libraries
const supertest = require('supertest');

/**
 * This is an example of an end-to-end test suite. The Loopback application
 * is initialized with a root path `/`. We are performing a full request to
 * hit the endpoint as if we were a client application.
 *
 * We are able to make the request and check that expected values are returned
 * in the `response.body`.
 */
describe('GET /', () => {

  // --------------------------------------------------
  // Initialize
  // --------------------------------------------------
  set('app', () => require('../../server/server'));

  // --------------------------------------------------
  // Request
  // --------------------------------------------------
  set('url', () => '/');
  action('request', () => supertest(app).get(url));

  beforeEach(async () => {
    response = await request();
  });

  it('should return a 200', () => {
    expect(response.status).toEqual(200);
  });

  it('should return when the server was started', () => {
    expect(response.body.started).toBeDefined();
  });

  it('should return the uptime of the server', () => {
    expect(response.body.uptime).toBeDefined();
  });
});
